RequestData

Enum RequestData 

pub enum RequestData {
    Load {
        fs: FsToken,
        runner_name: String,
        required_framework_version: VersionReq,
        runner_compat_version: u64,
        runner_opts: Option<HashMap<String, RunnerOpt>>,
        visible_device: Device,
        carton_manifest_hash: Option<String>,
    },
    Pack {
        fs: FsToken,
        input_path: String,
        temp_folder: String,
    },
    Seal {
        tensors: HashMap<String, Tensor>,
    },
    InferWithTensors {
        tensors: HashMap<String, Tensor>,
        streaming: bool,
    },
    InferWithHandle {
        handle: SealHandle,
        streaming: bool,
    },
}

Variants



Load

Fields

fs: FsToken

This filesystem points to a folder that is of the same structure as the output of Pack (for a particular runner) For a readonly filesystem

runner_name: String

Load options

required_framework_version: VersionReq
runner_compat_version: u64
visible_device: Device
carton_manifest_hash: Option<String>


Pack

Fields

fs: FsToken

A token for a read/write filesystem that the below paths reference

input_path: String
temp_folder: String


Seal

Fields



InferWithTensors

Fields

streaming: bool


InferWithHandle

Fields

handle: SealHandle
streaming: bool