pub struct SlowLog<T> { /* private fields */ }Implementations
Sourceimpl SlowLog<WithoutProgress>
impl SlowLog<WithoutProgress>
Sourcepub fn without_progress(self) -> Self
pub fn without_progress(self) -> Self
Just a hint to the compiler so it can figure out the type of T if we
never call set_progress or set_total