pub enum RequestData {
Load {
fs: FsToken,
runner_name: String,
required_framework_version: VersionReq,
runner_compat_version: u64,
runner_opts: Option<HashMap<String, RunnerOpt>>,
visible_device: Device,
carton_manifest_hash: Option<String>,
},
Pack {
fs: FsToken,
input_path: String,
temp_folder: String,
},
Seal {
tensors: HashMap<String, Tensor>,
},
InferWithTensors {
tensors: HashMap<String, Tensor>,
streaming: bool,
},
InferWithHandle {
handle: SealHandle,
streaming: bool,
},
}Variants
Load
Fields

fs: FsTokenThis filesystem points to a folder that is of the same structure as the output of Pack (for a particular runner)
For a readonly filesystem

required_framework_version: VersionReqPack
Fields
Seal
InferWithTensors
InferWithHandle